==> mx-packageinstaller-pkglist_19.05.06.tar.xz: mx-packageinstaller-pkglist/abiword.pm <==
<?xml version="1.0"?>
<app>

<category>
Office
</category>

<name>
Abiword
</name>

<description>
   <am>lightweight word processor</am>
   <ar>lightweight word processor</ar>
   <bg>lightweight word processor</bg>
   <ca>Processador de text lleuger</ca>
   <cs>lightweight word processor</cs>
   <da>letvægts tegnbehandler</da>
   <de>Eine voll funktionsfähige und effiziente Textverarbeitung</de>
   <el>ελαφρύ επεξεργαστή κειμένου</el>
   <en>lightweight word processor</en>
   <es>Procesador de textos liviano</es>
   <et>lightweight word processor</et>
   <eu>lightweight word processor</eu>
   <fa>lightweight word processor</fa>
   <fi>kevyt tekstinkäsittelyohjelma</fi>
   <fr>Traitement de texte léger</fr>
   <he_IL>lightweight word processor</he_IL>
   <hi>lightweight word processor</hi>
   <hr>lightweight word processor</hr>
   <hu>lightweight word processor</hu>
   <id>lightweight word processor</id>
   <is>lightweight word processor</is>
   <it>Editor di testo leggero</it>
   <ja_JP>lightweight word processor</ja_JP>
   <ja>lightweight word processor</ja>
   <kk>lightweight word processor</kk>
   <ko>lightweight word processor</ko>
   <lt>lightweight word processor</lt>
   <mk>lightweight word processor</mk>
   <nb>lightweight word processor</nb>
   <nl>lichtgewicht word processor</nl>
   <pl>lekki edytor tekstu</pl>
   <pt_BR>Processador de texto simples e ligeiro</pt_BR>
   <pt>Processador de texto simples e ligeiro</pt>
   <ro>lightweight word processor</ro>
   <ru>Легковесный текстовый редактор</ru>
   <sk>lightweight word processor</sk>
   <sl>lightweight word processor</sl>
   <sq>lightweight word processor</sq>
   <sr>lightweight word processor</sr>
   <sv>lättvikts ordbehandlare</sv>
   <tr>lightweight word processor</tr>
   <uk>легкий текстовий процесор</uk>
   <zh_CN>lightweight word processor</zh_CN>
   <zh_TW>lightweight word processor</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/013/886/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
abiword
abiword-common
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
abiword
abiword-common
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/abiword.pm <==
<?xml version="1.0"?>
<app>

<category>
Office
</category>

<name>
Abiword
</name>

<description>
   <am>lightweight word processor</am>
   <ar>lightweight word processor</ar>
   <bg>lightweight word processor</bg>
   <ca>Processador de text lleuger</ca>
   <cs>lightweight word processor</cs>
   <da>letvægts tegnbehandler</da>
   <de>Eine voll funktionsfähige und effiziente Textverarbeitung</de>
   <el>ελαφρύ επεξεργαστή κειμένου</el>
   <en>lightweight word processor</en>
   <es>Procesador de textos liviano</es>
   <et>lightweight word processor</et>
   <eu>lightweight word processor</eu>
   <fa>lightweight word processor</fa>
   <fi>kevyt tekstinkäsittelyohjelma</fi>
   <fr>Traitement de texte léger</fr>
   <he_IL>lightweight word processor</he_IL>
   <hi>lightweight word processor</hi>
   <hr>lightweight word processor</hr>
   <hu>lightweight word processor</hu>
   <id>lightweight word processor</id>
   <is>lightweight word processor</is>
   <it>Editor di testo leggero</it>
   <ja_JP>lightweight word processor</ja_JP>
   <ja>lightweight word processor</ja>
   <kk>lightweight word processor</kk>
   <ko>lightweight word processor</ko>
   <lt>lightweight word processor</lt>
   <mk>lightweight word processor</mk>
   <nb>lightweight word processor</nb>
   <nl>lichtgewicht word processor</nl>
   <pl>lekki edytor tekstu</pl>
   <pt_BR>Processador de texto simples e ligeiro</pt_BR>
   <pt>Processador de texto simples e ligeiro</pt>
   <ro>lightweight word processor</ro>
   <ru>Легковесный текстовый редактор</ru>
   <sk>ľahký textový editor</sk>
   <sl>lahek urejevalnik besedil</sl>
   <sq>lightweight word processor</sq>
   <sr>lightweight word processor</sr>
   <sv>lättvikts ordbehandlare</sv>
   <tr>lightweight word processor</tr>
   <uk>легкий текстовий процесор</uk>
   <zh_CN>lightweight word processor</zh_CN>
   <zh_TW>lightweight word processor</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/013/886/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
abiword
abiword-common
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
abiword
abiword-common
</uninstall_package_names>
</app>
